yakumo.cinder.v2.volume_backup.Resource

Package yakumo :: Package cinder :: Package v2 :: Module volume_backup :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

resource class for volume backups on Block Storage V2 API

Instance Methods | [hide private]
None |
restore(self, volume=None, transfer=None) Restore a volume from a volume backup | source code
None |
delete(self, force=False) Delete a volume backup | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `get_attrs`, `get_id`, `reload`, `update`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| _stable_state = ``[``'``available``'``,` `'``error``'``,` `'``error_deleting``'``]``
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### restore(self, volume=None, transfer=None) | source code
Restore a volume from a volume backup Parameters: `volume` (yakumo.cinder.v2.volume.Resource) - Destination volume `transfer` (yakumo.cinder.v2.volume_transfer.Resource) - Volume transfer Returns: None

### delete(self, force=False) | source code
Delete a volume backup Parameters: `force` (bool) - Whether the deletion is forced Returns: None Overrides: base.Resource.delete